package HSPC::Plugin::API::DM;

use strict;

use Data::Dumper;
use Error qw(:try);

use HSPC::System;
use HSPC::Config;
use HSPC::Logger;
use HSPC::Localization qw(:DEFAULT set_language);
use HSPC::PluginToolkit::General qw(argparam);
use HSPC::Plugin::API::Common qw(prepare_account_from_soap prepare_hash_from_soap APIResult APIResultErrors);

use HSPC::MT::Core::Constants;
use HSPC::MT::PluginConfig;
use HSPC::MT::PluginTools;
##use HSPC::MT::CCP::Constants qw(:DEFAULT :status :permissions :process :credit_types :trans_types);

use HSPC::Plugin::SOAP::Struct::APIResult;
use HSPC::Plugin::SOAP::Struct::FormResult;
use HSPC::Plugin::SOAP::Struct::CollectedResult;
use HSPC::Plugin::SOAP::Struct::HelpPageResult;

use HSPC::Exception::Plugin::InvalidParameter;
use HSPC::Exception::Plugin::GeneralError;

use constant PLUGIN_TYPE => "DM";
use constant SW_CCP_TRANS_TYPE_CALLBACK => 10;

sub view_config_form($$)
{
	my $me		= shift;
	my $args	= shift;

	my $user_error;
	my $fatal_error;
	my $other_error;
	my $form_content;

	set_language($args->{language});

	try
	{
		my $template_id	= $args->{template_id};

		HSPC::MT::PluginTools::set_request_data(template_id => $template_id);
		HSPC::MT::PluginTools::set_request_data(callback_url => $args->{callback_url});

		my $plugin_data	= prepare_hash_from_soap($args->{plugin_data}, {});
		my $request		= prepare_hash_from_soap($args->{request_context}, {}, 1);

		HSPC::Plugin::API::Common->init_request($request, $template_id);

		my $templates = HSPC::Plugin::API::Common->get_plugin_templates(PLUGIN_TYPE, $template_id);

		$form_content = $templates->{pr_template}->view_config_form(config => $plugin_data);
	}
	catch HSPC::Exception::Plugin::InvalidParameter with
	{
		$user_error = shift;
		$user_error = "".$user_error->{message};
	}
	catch HSPC::Exception::Plugin::GeneralError with
	{
		$user_error = shift;
		$user_error = "".$user_error->{vendor_message};
	}
	catch HSPC::Exc::Fatal with
	{
		$fatal_error = shift;
	}
	otherwise
	{
		$other_error = shift;
	};

	return APIResultErrors(
		"Fatal error has occured: ".$fatal_error->{msg}.". Calls stack: ".$fatal_error->{calls_stack},
		"Exception's dump: ".Dumper($fatal_error)
	) if $fatal_error;

	return APIResultErrors(
		"Unknown error has occured: {".$other_error->{-text}." in ".$other_error->{-file}."} at line ".$other_error->{-line},
		"Exception's dump: ".Dumper($other_error)
	) if $other_error;

	return APIResult(HSPC::Plugin::SOAP::Struct::FormResult->new(
		form_content => HSPC::Plugin::API::Common->add_common_js($form_content),
		form_onsubmit_js => "",
		user_error => $user_error,
	));
}

sub edit_config_form($$)
{
	my $me		= shift;
	my $args	= shift;

	my $user_error;
	my $fatal_error;
	my $other_error;
	my $form_content;

	set_language($args->{language});

	try
	{
		my $template_id	= $args->{template_id};

		HSPC::MT::PluginTools::set_request_data(template_id => $template_id);
		HSPC::MT::PluginTools::set_request_data(callback_url => $args->{callback_url});

		my $plugin_data	= prepare_hash_from_soap($args->{plugin_data}, {});
		my $request		= prepare_hash_from_soap($args->{request_context}, {}, 1);

		#use Data::Dumper;
		#die(Dumper($args->{request_context}));
		#die(Dumper($request));

		HSPC::Plugin::API::Common->init_request($request, $template_id);

		my $templates = HSPC::Plugin::API::Common->get_plugin_templates(PLUGIN_TYPE, $template_id);

		$form_content = $templates->{pr_template}->edit_config_form(config => $plugin_data)
	}
	catch HSPC::Exception::Plugin::InvalidParameter with
	{
		$user_error = shift;
		$user_error = "".$user_error->{message};
	}
	catch HSPC::Exception::Plugin::GeneralError with
	{
		$user_error = shift;
		$user_error = "".$user_error->{vendor_message};
	}
	catch HSPC::Exc::Fatal with
	{
		$fatal_error = shift;
	}
	otherwise
	{
		$other_error = shift;
	};

	return APIResultErrors(
		"Fatal error has occured: ".$fatal_error->{msg}.". Calls stack: ".$fatal_error->{calls_stack},
		"Exception's dump: ".Dumper($fatal_error)
	) if $fatal_error;

	return APIResultErrors(
		"Unknown error has occured: {".$other_error->{-text}." in ".$other_error->{-file}."} at line ".$other_error->{-line},
		"Exception's dump: ".Dumper($other_error)
	) if $other_error;

	return APIResult(HSPC::Plugin::SOAP::Struct::FormResult->new(
		form_content => HSPC::Plugin::API::Common->add_common_js($form_content),
		form_onsubmit_js => "",
		user_error => $user_error,
	));
}

sub collect_config_data($$)
{
	my $me		= shift;
	my $args	= shift;

	my $user_error;
	my $fatal_error;
	my $other_error;
	my $collected_data;

	set_language($args->{language});

	try
	{
		my $template_id	= $args->{template_id};

		HSPC::MT::PluginTools::set_request_data(template_id => $template_id);
		HSPC::MT::PluginTools::set_request_data(callback_url => $args->{callback_url});

		my $plugin_data	= prepare_hash_from_soap($args->{plugin_data}, {});
		my $request		= prepare_hash_from_soap($args->{request_context}, {}, 1);

		HSPC::Plugin::API::Common->init_request($request, $template_id);

		my $templates = HSPC::Plugin::API::Common->get_plugin_templates(PLUGIN_TYPE, $template_id);

		$collected_data = $templates->{pr_template}->collect_config_data(config => $plugin_data)->{config};
	}
	catch HSPC::Exception::Plugin::InvalidParameter with
	{
		$user_error = shift;
		$user_error = "".$user_error->{message};
	}
	catch HSPC::Exception::Plugin::GeneralError with
	{
		$user_error = shift;
		$user_error = "".$user_error->{vendor_message};
	}
	catch HSPC::Exc::Fatal with
	{
		$fatal_error = shift;
	}
	otherwise
	{
		$other_error = shift;
	};

	return APIResultErrors(
		"Fatal error has occured: ".$fatal_error->{msg}.". Calls stack: ".$fatal_error->{calls_stack},
		"Exception's dump: ".Dumper($fatal_error)
	) if $fatal_error;

	return APIResultErrors(
		"Unknown error has occured: {".$other_error->{-text}." in ".$other_error->{-file}."} at line ".$other_error->{-line},
		"Exception's dump: ".Dumper($other_error)
	) if $other_error;

	return APIResult(HSPC::Plugin::SOAP::Struct::CollectedResult->new(
		plugin_data => $collected_data,
		user_error => $user_error,
	));
}

1;
